# BonziBuddy
### Welcome To BonziBuddy - Official [Python 3.8.5]
##### For Quires You Can Email Me AT - `akashpattnaik.github@gmail.com` ![BonziBuddy](https://github.com/BLUE-DEVIL1134/BonziBuddy/blob/master/BonziBuddy/bonzi.png)
## [Latest Update](https://github.com/BLUE-DEVIL1134/BonziBuddy/blob/master/Updates/06-09-2020.update)

## Information
```jquery-css
BonziBuddy, stylized as BonziBUDDY, 
was a freeware desktop virtual assistant made by Joe and Jay Bonzi. 
Upon a user's choice, it would share jokes and facts, 
manage downloading using its download manager, sing songs, 
and talk, among other functions.
```

## Possibilities
| Possibility   |      Yes / No      |
|----------|:-------------:|
| Open Websites |  Yes |
| Open Games |    Yes   |
| Speak | Yes  |
| Take Voice Command | No (For Now)  |
| Animation | No (For Now)  |
| Open Apps | Yes  |
| Send Mails | Yes (Version 1.2 and Higher)  |
| Open Directories | Yes  |
| Capture The World | Yes (This Has Already Been Done) |

`The Possibilities Are Acctually Endless...`

**As You See Avobe,**
**The World Capture Has Been Done By BonziBuddy Once**
**Its Say To Know That Today's Generation Does'nt Knows About This** 

# Installation
**So Now Comes Installation,**
**As Said Above, This Is In Pure Python, So You Can Download It From Pypi Directly...**

### Installation With [Pypi](https://pypi.org/user/AkashPattnaik)

```jetpack
pip install BonziBuddy
         OR
pip3 install BonziBuddy
```

### Installation With [Git](https://github.com/BLUE-DEVIL1134)

```jetpack
git clone https://github.com/BLUE-DEVIL1134/BonziBuddy
cd BonziBuddy
python setup.py install
```

# Usage
#### You can Use This Directly In The Terminal...
**Open Terminal And Type In:**
```jetpack
bonzi
```

##### The Output Will Be - 
```jetpack
  ____                  _   ____            _     _       
 | __ )  ___  _ __  ___(_) | __ ) _   _  __| | __| |_   _ 
 |  _ \ / _ \| '_ \|_  / | |  _ \| | | |/ _` |/ _` | | | |
 | |_) | (_) | | | |/ /| | | |_) | |_| | (_| | (_| | |_| |
 |____/ \___/|_| |_/___|_| |____/ \__,_|\__,_|\__,_|\__, |
                                                    |___/ 
Command Me :
```

#### Now Enter What You Want BonziBuddy To Do - 
```jetpack
  ____                  _   ____            _     _       
 | __ )  ___  _ __  ___(_) | __ ) _   _  __| | __| |_   _ 
 |  _ \ / _ \| '_ \|_  / | |  _ \| | | |/ _` |/ _` | | | |
 | |_) | (_) | | | |/ /| | | |_) | |_| | (_| | (_| | |_| |
 |____/ \___/|_| |_/___|_| |____/ \__,_|\__,_|\__,_|\__, |
                                                    |___/ 
Command Me : hello Bonzi
```
```Then Click Enter...```

#### BonziBuddy Will Say Hello To You Back
**Well You Cant See But It Will Speak - Check Out The Response `Here:`**
![Example Pic](https://github.com/BLUE-DEVIL1134/BonziBuddy/blob/master/examples/bonzi_example.png)
